FlutterP2pConnectionPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterP2pConnectionPlatform
Implementers

Constructors

FlutterP2pConnectionPlatform()
Constructs a FlutterP2pConnectionPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

askP2pPermissions() → Future<void>
checkBluetoothEnabled() → Future<bool>
checkLocationEnabled() → Future<bool>
checkP2pPermissions() → Future<bool>
checkWifiEnabled() → Future<bool>
connectBleDevice(String deviceAddress) → Future<void>
connectToHotspot(String ssid, String psk) → Future<void>
createHotspot() → Future<void>
disconnectBleDevice(String deviceAddress) → Future<void>
disconnectFromHotspot() → Future<void>
dispose() → Future<void>
enableBluetoothServices() → Future<void>
enableLocationServices() → Future<void>
enableWifiServices() → Future<void>
getPlatformModel() → Future<String>
getPlatformVersion() → Future<String>
initialize({String? serviceUuid, bool? bondingRequired, bool? encryptionRequired}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeHotspot() → Future<void>
startBleAdvertising(String ssid, String psk) → Future<void>
startBleScan() → Future<void>
stopBleAdvertising() → Future<void>
stopBleScan() → Future<void>
streamBleConnectionState() → Stream<BleConnectionState>
streamBleReceivedData() → Stream<BleReceivedData>
streamBleScanResult() → Stream<List<BleDiscoveredDevice>>
streamHotspotClientState() → Stream<HotspotClientState>
streamHotspotInfo() → Stream<HotspotHostState>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterP2pConnectionPlatform
The default instance of FlutterP2pConnectionPlatform to use.
getter/setter pair